@@ -150,7 +150,7 @@ process_line (char     *line,
 		    || (fields[5][0] == 'd')) {
 			file_data_free (fdata);
 		} else {
-			fdata->size = atoll (fields[0]);
+			fdata->size = g_ascii_strtoull (fields[0], NULL, 10);
 			fdata->modified = mktime_from_string (fields[3], fields[4]); 
 			comm->file_list = g_list_prepend (comm->file_list, fdata);
 		}
@@ -247,6 +247,9 @@ fr_command_rar_add (FRCommand     *comm,
 	}
 
 	add_password_arg (comm, password, FALSE);
+
+	/* disable percentage indicator */
+	fr_process_add_arg (comm->process, "-idp");
 	
 	/* stop switches scanning */
 	fr_process_add_arg (comm->process, "--"); 
@@ -310,6 +313,9 @@ fr_command_rar_extract (FRCommand  *comm,
 		fr_process_add_arg (comm->process, "-ep");
 	
 	add_password_arg (comm, password, TRUE);
+
+	/* disable percentage indicator */
+	fr_process_add_arg (comm->process, "-idp");
 	
 	/* stop switches scanning */
 	fr_process_add_arg (comm->process, "--"); 
@@ -341,7 +347,10 @@ fr_command_rar_test (FRCommand   *comm,
 	fr_process_add_arg (comm->process, "t");
 	
 	add_password_arg (comm, password, TRUE);
-	
+
+	/* disable percentage indicator */
+	fr_process_add_arg (comm->process, "-idp");
+
 	/* stop switches scanning */
 	fr_process_add_arg (comm->process, "--");
 	
