@@ -86,7 +86,7 @@ list__process_line (char     *line,
 	fdata = file_data_new ();
 
 	fields = split_line (line, 8);
-	fdata->size = atoll (fields[4]);
+	fdata->size = g_ascii_strtoull (fields[4], NULL, 10);
 	fdata->modified = mktime_from_string (fields[5], fields[6], fields[7]);
 	g_strfreev (fields);
 
