@@ -134,7 +134,7 @@ process_line (char     *line,
 	date_idx = file_list__get_index_from_pattern (line, "%n%n%n%n-%n%n-%n%n %n%n:%n%n");
 
 	field_size = file_list__get_prev_field (line, date_idx, 1);
-	fdata->size = atol (field_size);
+	fdata->size = g_ascii_strtoull (field_size, NULL, 10);
 	g_free (field_size);
 
 	field_date = file_list__get_next_field (line, date_idx, 1);
@@ -750,7 +750,7 @@ fr_command_tar_escape (FRCommand     *comm,
 	char *estr;
 	char *estr2;
 
-        estr = escape_str (str, "?*\\'& !|()@#:;");
+        estr = escape_str (str, "$?*\\'& !|()@#:;");
         estr2 = escape_str_common (estr, "[]", '[', ']');
 	g_free (estr);
 
