@@ -3,7 +3,7 @@
 /*
  *  File-Roller
  *
- *  Copyright (C) 2003 The Free Software Foundation, Inc.
+ *  Copyright (C) 2003 Free Software Foundation, Inc.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -45,14 +45,14 @@ static FRCommandClass *parent_class = NULL;
 /* -- list -- */
 
 static time_t
-mktime_from_zoo_string (gchar *mday_s,
-			gchar *month_s,
-			gchar *year_s,
-			gchar *time_s)
+mktime_from_string_zoo (char *mday_s,
+			char *month_s,
+			char *year_s,
+			char *time_s)
 {
-	struct tm   tm = {0, };
-	gchar **fields;
-	gint year;
+	struct tm  tm = {0, };
+	char **fields;
+	int year;
 
 	/* This will break in 2075 */
 	year = atoi (year_s);
@@ -106,43 +106,35 @@ mktime_from_zoo_string (gchar *mday_s,
 }
 
 
-static gchar *
-eat_spaces (gchar *line)
+static char **
+split_line_zoo (char *line)
 {
-	while ((*line == ' ') && (*line != 0))
-		line++;
-	return line;
-}
-
-static gchar **
-split_zoo_line (gchar *line)
-{
-	gchar **fields;
-	gchar *scan, *field_end;
-	gint i;
+	char       **fields;
+	const char  *scan, *field_end;
+	int          i;
 
 	if (line[0] == '-') {
 		return NULL;
 	}
 
-	fields = g_new0 (gchar *, 6);
+	fields = g_new0 (char *, 6);
 	fields[5] = NULL;
 
-	// Get Length
+	/* Get Length */
 	scan = eat_spaces (line);
 	field_end = strchr (scan, ' ');
 	fields[0] = g_strndup (scan, field_end - scan);
 	scan = eat_spaces (field_end);
 
-	// Toss CF, Size Now
+	/* Toss CF, Size Now */
 	for (i = 0; i < 2; i++) {
 		field_end = strchr (scan, ' ');
 		scan = eat_spaces (field_end);
 	}
 
-	// Get Day, Month, Year, Time
+	/* Get Day, Month, Year, Time */
 	for (i = 1; i < 5; i++) {
-		if (i == 2 && g_ascii_strncasecmp(scan, "file", 4) == 0) {
+		if (i == 2 && g_ascii_strncasecmp (scan, "file", 4) == 0) {
 			g_strfreev(fields);
 			return NULL;
 		}
@@ -154,12 +146,13 @@ split_zoo_line (gchar *line)
 	return fields;
 }
 
-static gchar *
-get_last_field (gchar *line)
+
+static const char *
+get_last_field_zoo (char *line)
 {
-	gint   i;
-	gchar *field;
-	gint   n = 6;
+	const char *field;
+	int         i;
+	int         n = 6;
 
 	field = eat_spaces (line);
 	for (i = 0; i < n; i++) {
@@ -171,36 +164,34 @@ get_last_field (gchar *line)
 		field = eat_spaces (field);
 		field = strchr (field, ' ');
 		field = eat_spaces (field);
-	} else {
+	} else 
 		field = eat_spaces (field);
-	}
-	field = strchr (field, ' ');
-	field = eat_spaces (field);
 
 	return field;
 }
 
+
 static void
-process_zoo_line (gchar     *line, 
-	      gpointer  data)
+process_zoo_line (char     *line, 
+		  gpointer  data)
 {
-	FileData   *fdata;
-	FRCommand  *zoo_comm = FR_COMMAND (data);
-	gchar      **fields;
-	gchar       *name_field;
+	FileData    *fdata;
+	FRCommand   *zoo_comm = FR_COMMAND (data);
+	char       **fields;
+	const char  *name_field;
 
 	g_return_if_fail (line != NULL);
 	if (line[0] == '-')
 		return;
 
-	fields = split_zoo_line (line);
+	fields = split_line_zoo (line);
 	if (fields == NULL)
 		return;
 
 	fdata = file_data_new ();
 
-	fdata->size = atol (fields[0]);
-	fdata->modified = mktime_from_zoo_string (fields[1],
+	fdata->size = g_ascii_strtoull (fields[0], NULL, 10);
+	fdata->modified = mktime_from_string_zoo (fields[1],
 						  fields[2],
 						  fields[3],
 						  fields[4]);
@@ -208,7 +199,7 @@ process_zoo_line (gchar     *line,
 
 	/* Full path */
 
-	name_field = get_last_field (line);
+	name_field = get_last_field_zoo (line);
 	if (*(name_field) == '/') {
 		fdata->full_path = g_strdup (name_field);
 		fdata->original_path = fdata->full_path;
@@ -227,6 +218,7 @@ process_zoo_line (gchar     *line,
 		zoo_comm->file_list = g_list_prepend (zoo_comm->file_list, fdata);
 }
 
+
 static void
 fr_command_zoo_list (FRCommand *zoo_comm)
 {
@@ -234,9 +226,8 @@ fr_command_zoo_list (FRCommand *zoo_comm)
 				      process_zoo_line,
 				      zoo_comm);
 
-	fr_process_clear (zoo_comm->process);
 	fr_process_begin_command (zoo_comm->process, "zoo");
-	fr_process_add_arg (zoo_comm->process, "la");
+	fr_process_add_arg (zoo_comm->process, "lq");
 	fr_process_add_arg (zoo_comm->process, zoo_comm->e_filename);
 	fr_process_end_command (zoo_comm->process);
 	fr_process_start (zoo_comm->process);
@@ -257,11 +248,10 @@ fr_command_zoo_add (FRCommand     *comm,
 
 	fr_process_begin_command (comm->process, "zoo");
 
-	if (base_dir != NULL)
-		fr_process_set_working_dir (comm->process, base_dir);
+	fr_process_set_working_dir (comm->process, base_dir);
 
 	if (update) 
-		fr_process_add_arg (comm->process, "aunP");
+		fr_process_add_arg (comm->process, "auP");
 	else
 		fr_process_add_arg (comm->process, "aP");
 
@@ -272,6 +262,7 @@ fr_command_zoo_add (FRCommand     *comm,
 	fr_process_end_command (comm->process);
 }
 
+
 static void
 fr_command_zoo_delete (FRCommand *comm,
 		       GList     *file_list)
@@ -289,6 +280,7 @@ fr_command_zoo_delete (FRCommand *comm,
 	fr_process_end_command (comm->process);
 }
 
+
 static void
 fr_command_zoo_extract (FRCommand  *comm,
 			GList      *file_list,
@@ -318,6 +310,18 @@ fr_command_zoo_extract (FRCommand  *comm,
 	fr_process_end_command (comm->process);
 }
 
+
+static void
+fr_command_zoo_test (FRCommand   *comm,
+		     const char  *password)
+{
+	fr_process_begin_command (comm->process, "zoo");
+	fr_process_add_arg (comm->process, "-test");
+	fr_process_add_arg (comm->process, comm->e_filename);
+	fr_process_end_command (comm->process);
+}
+
+
 static void 
 fr_command_zoo_class_init (FRCommandZooClass *class)
 {
@@ -333,6 +337,7 @@ fr_command_zoo_class_init (FRCommandZooClass *class)
 	afc->add          = fr_command_zoo_add;
 	afc->delete       = fr_command_zoo_delete;
 	afc->extract      = fr_command_zoo_extract;
+	afc->test         = fr_command_zoo_test;
 }
 
  
@@ -345,7 +350,7 @@ fr_command_zoo_init (FRCommand *comm)
 	comm->propExtractCanSkipOlder      = FALSE;
 	comm->propExtractCanJunkPaths      = FALSE;
 	comm->propPassword                 = FALSE;
-	comm->propTest                     = FALSE;
+	comm->propTest                     = TRUE;
 }
 
 
@@ -364,7 +369,7 @@ fr_command_zoo_finalize (GObject *object)
 GType
 fr_command_zoo_get_type ()
 {
-        static guint type = 0;
+        static GType type = 0;
 
         if (! type) {
                 GTypeInfo type_info = {
@@ -394,6 +399,10 @@ fr_command_zoo_new (FRProcess         *process,
 {
 	FRCommand *comm;
 
+	if (!is_program_in_path("zoo")) {
+		return NULL;
+	}	
+
 	comm = FR_COMMAND (g_object_new (FR_TYPE_COMMAND_ZOO, NULL));
 	fr_command_construct (comm, process, filename);
 
